@@ -1,12 +1,12 @@
 ######################################################################
 # search_fuzzy.inc.pl - This is PyukiWiki, yet another Wiki clone.
-# $Id: search_fuzzy.inc.pl,v 1.52 2006/03/17 14:00:10 papu Exp $
+# $Id: search_fuzzy.inc.pl,v 1.85 2011/01/25 03:11:15 papu Exp $
 #
-# "PyukiWiki" version 0.1.6 $$
-# Author: Nanami http://lineage.netgamers.jp/
-# Copyright (C) 2004-2006 by Nekyo.
-# http://nekyo.hp.infoseek.co.jp/
-# Copyright (C) 2005-2006 PyukiWiki Developers Team
+# "PyukiWiki" version 0.1.8-p2 $$
+# Author: Nanami http://nanakochi.daiba.cx/
+# Copyright (C) 2004-2011 by Nekyo.
+# http://nekyo.qp.land.to/
+# Copyright (C) 2005-2011 PyukiWiki Developers Team
 # http://pyukiwiki.sourceforge.jp/
 # Based on YukiWiki http://www.hyuki.com/yukiwiki/
 # Powerd by PukiWiki http://pukiwiki.sourceforge.jp/
@@ -26,7 +26,7 @@ use Nana::Search;
 
 sub plugin_fuzzy_search {
 	my $body = "";
-	my $word=&escape(&code_convert(\$::form{search}, $::defaultcode));
+	my $word=&escape(&code_convert(\$::form{mymsg}, $::defaultcode));
 	if ($word) {
 		@words = split(/\s+/, $word);
 		my $total = 0;
